@@ -2,12 +2,31 @@ package Alien::TidyHTML5;
 
 # ABSTRACT: Download and install HTML Tidy
 
+use v5.8;
+
 use strict;
 use warnings;
 
 use base qw/ Alien::Base /;
 
-our $VERSION = 'v0.1.1';
+
+use File::Spec::Functions qw/ catfile /;
+use List::Util qw/ first /;
+
+use namespace::autoclean;
+
+our $VERSION = 'v0.2.0';
+
+
+sub exe_file {
+    my ($self) = @_;
+    if ( my $bin = $self->bin_dir ) {
+        return first { -x $_ } map { catfile( $bin, $_ ) } qw/ tidy tidy5 /;
+    }
+    else {
+        return undef;
+    }
+}
 
 
 1;
@@ -24,7 +43,7 @@ Alien::TidyHTML5 - Download and install HTML Tidy
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 DESCRIPTION
 
@@ -36,6 +55,12 @@ cannot be found, the source code will be downloaded from the official
 git repository, and it will be installed in a private share location
 for the use of other modules.
 
+=head1 METHODS
+
+=head2 C<exe_file>
+
+This returns the path of the F<tidy> executable.
+
 =head1 SEE ALSO
 
 L<http://www.html-tidy.org/>
@@ -63,6 +88,12 @@ Robert Rothenberg <rrwo@cpan.org>
 The initial development of this module was sponsored by Science Photo
 Library L<https://www.sciencephoto.com>.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Slaven Rezić
+
+Slaven Rezić <slaven@rezic.de>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018 by Robert Rothenberg.
